@@ -27,8 +27,8 @@
  * \brief dequeコンテナ
  * \author KATO Noriaki <katono@users.sourceforge.jp>
  * \date 2007-04-01
- * $URL: http://svn.sourceforge.jp/svnroot/cstl/tags/rel-0.6.0/cstl/deque.h $
- * $Id: deque.h 264 2009-04-17 02:29:36Z katono $
+ * $URL: http://svn.sourceforge.jp/svnroot/cstl/tags/rel-0.6.2/cstl/deque.h $
+ * $Id: deque.h 278 2009-05-19 06:43:20Z katono $
  */
 #ifndef CSTL_DEQUE_H_INCLUDED
 #define CSTL_DEQUE_H_INCLUDED
@@ -46,10 +46,10 @@
 #define CSTL_DEQUE_END_EXTERN_C()
 #endif
 
-#ifndef NDEBUG
-#define CSTL_DEQUE_MAGIC(x) x
-#else
+#ifdef NDEBUG
 #define CSTL_DEQUE_MAGIC(x)
+#else
+#define CSTL_DEQUE_MAGIC(x) x
 #endif
 
 #ifndef CSTL_ALGORITHM_INTERFACE
