@@ -27,8 +27,8 @@
  * \brief map/multimapコンテナ
  * \author KATO Noriaki <katono@users.sourceforge.jp>
  * \date 2006-11-11
- * $URL: http://svn.sourceforge.jp/svnroot/cstl/tags/rel-0.6.1/cstl/map.h $
- * $Id: map.h 264 2009-04-17 02:29:36Z katono $
+ * $URL: http://svn.sourceforge.jp/svnroot/cstl/tags/rel-0.6.2/cstl/map.h $
+ * $Id: map.h 277 2009-05-19 01:05:52Z katono $
  */
 #ifndef CSTL_MAP_H_INCLUDED
 #define CSTL_MAP_H_INCLUDED
@@ -187,9 +187,8 @@ ValueType *Name##_at(Name *self, KeyType key)\
 	assert(self->magic == self && "Map_at");\
 	pos = Name##RBTree_find(self->tree, key);\
 	if (pos == Name##RBTree_end(self->tree)) {\
-		/* 新しい要素の値 */\
-		static ValueType value;\
-		pos = Name##RBTree_new_node(&key, &value, CSTL_RBTREE_RED);\
+		/* 新しい要素の値にはnilの値を使用 */\
+		pos = Name##RBTree_new_node(&key, &Name##RBTree_nil.value, CSTL_RBTREE_RED);\
 		if (pos) {\
 			Name##RBTree_insert(self->tree, pos);\
 			self->size++;\
