@@ -27,8 +27,8 @@
  * \brief 赤黒木
  * \author KATO Noriaki <katono@users.sourceforge.jp>
  * \date 2006-10-29
- * $URL: http://svn.sourceforge.jp/svnroot/cstl/tags/rel-0.6.1/cstl/rbtree.h $
- * $Id: rbtree.h 264 2009-04-17 02:29:36Z katono $
+ * $URL: http://svn.sourceforge.jp/svnroot/cstl/tags/rel-0.6.2/cstl/rbtree.h $
+ * $Id: rbtree.h 278 2009-05-19 06:43:20Z katono $
  *
  * このファイルを直接インクルードしないこと
  */
@@ -38,10 +38,10 @@
 #include <stdlib.h>
 #include <assert.h>
 
-#ifndef NDEBUG
-#define CSTL_RBTREE_MAGIC(x) x
-#else
+#ifdef NDEBUG
 #define CSTL_RBTREE_MAGIC(x)
+#else
+#define CSTL_RBTREE_MAGIC(x) x
 #endif
 
 /*! 
