@@ -27,8 +27,8 @@
  * \brief リングバッファ
  * \author KATO Noriaki <katono@users.sourceforge.jp>
  * \date 2006-02-25
- * $URL: http://svn.sourceforge.jp/svnroot/cstl/tags/rel-0.6.1/cstl/ring.h $
- * $Id: ring.h 264 2009-04-17 02:29:36Z katono $
+ * $URL: http://svn.sourceforge.jp/svnroot/cstl/tags/rel-0.6.2/cstl/ring.h $
+ * $Id: ring.h 278 2009-05-19 06:43:20Z katono $
  */
 #ifndef CSTL_RING_H_INCLUDED
 #define CSTL_RING_H_INCLUDED
@@ -44,10 +44,10 @@
 #define CSTL_RING_END_EXTERN_C()
 #endif
 
-#ifndef NDEBUG
-#define CSTL_RING_MAGIC(x) x
-#else
+#ifdef NDEBUG
 #define CSTL_RING_MAGIC(x)
+#else
+#define CSTL_RING_MAGIC(x) x
 #endif
 
 
