@@ -27,8 +27,8 @@
  * \brief 文字列コンテナ
  * \author KATO Noriaki <katono@users.sourceforge.jp>
  * \date 2007-01-09
- * $URL: http://svn.sourceforge.jp/svnroot/cstl/tags/rel-0.6.1/cstl/string.h $
- * $Id: string.h 264 2009-04-17 02:29:36Z katono $
+ * $URL: http://svn.sourceforge.jp/svnroot/cstl/tags/rel-0.6.2/cstl/string.h $
+ * $Id: string.h 278 2009-05-19 06:43:20Z katono $
  */
 #ifndef CSTL_STRING_H_INCLUDED
 #define CSTL_STRING_H_INCLUDED
@@ -45,10 +45,10 @@
 #define CSTL_STRING_END_EXTERN_C()
 #endif
 
-#ifndef NDEBUG
-#define CSTL_STRING_MAGIC(x) x
-#else
+#ifdef NDEBUG
 #define CSTL_STRING_MAGIC(x)
+#else
+#define CSTL_STRING_MAGIC(x) x
 #endif
 
 #ifndef CSTL_ALGORITHM_INTERFACE
