@@ -3,13 +3,13 @@
 #include <assert.h>
 #include <limits.h>
 #include "../cstl/deque.h"
-#include "heap.h"
+#include "Pool.h"
 #ifdef MY_MALLOC
 double buf[1024*1024/sizeof(double)];
-Heap heap;
-#define malloc(s)		Heap_alloc(&heap, s)
-#define realloc(p, s)	Heap_realloc(&heap, p, s)
-#define free(p)			Heap_free(&heap, p)
+Pool pool;
+#define malloc(s)		Pool_malloc(&pool, s)
+#define realloc(p, s)	Pool_realloc(&pool, p, s)
+#define free(p)			Pool_free(&pool, p)
 #endif
 
 
@@ -124,7 +124,7 @@ void DequeTest_test_1_1(void)
 	UCharDeque_clear(ud);
 	assert(UCharDeque_size(ud) == 0);
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	UCharDeque_delete(ud);
 }
 
@@ -150,12 +150,12 @@ void DequeTest_test_1_2(void)
 	assert(!UCharDeque_empty(ud));
 /*    UCharDeque_print(ud);*/
 	/* front */
-	assert(UCharDeque_front(ud) == hoge[0]);
+	assert(*UCharDeque_front(ud) == hoge[0]);
 	/* back */
-	assert(UCharDeque_back(ud) == hoge[MAX-1]);
+	assert(*UCharDeque_back(ud) == hoge[MAX-1]);
 	/* pop_front */
 	size = UCharDeque_size(ud);
-	assert(UCharDeque_pop_front(ud) == hoge[0]);
+	UCharDeque_pop_front(ud);
 	assert(UCharDeque_size(ud) == size - 1);
 	assert(UCharDeque_verify(ud));
 	/* push_back */
@@ -171,9 +171,11 @@ void DequeTest_test_1_2(void)
 	for (i = 0; i < MAX; i++) {
 		size = UCharDeque_size(ud);
 		if (i < MAX-1) {
-			assert(UCharDeque_pop_front(ud) == hoge[i+1]);
+			assert(*UCharDeque_front(ud) == hoge[i+1]);
+			UCharDeque_pop_front(ud);
 		} else {
-			assert(UCharDeque_pop_front(ud) == hoge[0]);
+			assert(*UCharDeque_front(ud) == hoge[0]);
+			UCharDeque_pop_front(ud);
 		}
 		assert(UCharDeque_size(ud) == size - 1);
 		assert(UCharDeque_verify(ud));
@@ -194,7 +196,7 @@ void DequeTest_test_1_2(void)
 	UCharDeque_clear(ud);
 /*    UCharDeque_print(ud);*/
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	UCharDeque_delete(ud);
 }
 
@@ -219,13 +221,15 @@ void DequeTest_test_1_3(void)
 	assert(UCharDeque_size(ud) == MAX);
 	assert(!UCharDeque_empty(ud));
 	/* front */
-	assert(UCharDeque_front(ud) == hoge[0]);
+	assert(*UCharDeque_front(ud) == hoge[0]);
 	/* back */
-	assert(UCharDeque_back(ud) == hoge[MAX-1]);
+	assert(*UCharDeque_back(ud) == hoge[MAX-1]);
 	/* pop_back */
 	size = UCharDeque_size(ud);
-	assert(UCharDeque_pop_back(ud) == hoge[MAX-1]);
-	assert(UCharDeque_pop_back(ud) == hoge[MAX-2]);
+	assert(*UCharDeque_back(ud) == hoge[MAX-1]);
+	UCharDeque_pop_back(ud);
+	assert(*UCharDeque_back(ud) == hoge[MAX-2]);
+	UCharDeque_pop_back(ud);
 	assert(UCharDeque_size(ud) == size - 2);
 	assert(UCharDeque_verify(ud));
 	/* push_front */
@@ -241,12 +245,15 @@ void DequeTest_test_1_3(void)
 	/* pop_back */
 	for (i = MAX-3; i >= 0; i--) {
 		size = UCharDeque_size(ud);
-		assert(UCharDeque_pop_back(ud) == hoge[i]);
+		assert(*UCharDeque_back(ud) == hoge[i]);
+		UCharDeque_pop_back(ud);
 		assert(UCharDeque_size(ud) == size - 1);
 		assert(UCharDeque_verify(ud));
 	}
-	assert(UCharDeque_pop_back(ud) == hoge[MAX-1]);
-	assert(UCharDeque_pop_back(ud) == hoge[MAX-2]);
+	assert(*UCharDeque_back(ud) == hoge[MAX-1]);
+	UCharDeque_pop_back(ud);
+	assert(*UCharDeque_back(ud) == hoge[MAX-2]);
+	UCharDeque_pop_back(ud);
 
 	assert(UCharDeque_size(ud) == 0);
 	assert(UCharDeque_empty(ud));
@@ -260,7 +267,7 @@ void DequeTest_test_1_3(void)
 	assert(!UCharDeque_empty(ud));
 	assert(UCharDeque_verify(ud));
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	UCharDeque_delete(ud);
 }
 
@@ -360,7 +367,7 @@ void DequeTest_test_1_4(void)
 	assert(UCharDeque_size(ud) == 0);
 	assert(UCharDeque_verify(ud));
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	UCharDeque_delete(ud);
 }
 
@@ -506,7 +513,7 @@ void DequeTest_test_1_5(void)
 	assert(UCharDeque_size(ud) == 0);
 	assert(UCharDeque_verify(ud));
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	UCharDeque_delete(ud);
 }
 
@@ -636,7 +643,7 @@ void DequeTest_test_1_6(void)
 
 
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	UCharDeque_delete(ud);
 	UCharDeque_delete(x);
 }
@@ -680,7 +687,7 @@ void DequeTest_test_2_1(void)
 	IntDeque_clear(id);
 	assert(IntDeque_size(id) == 0);
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	IntDeque_delete(id);
 }
 
@@ -703,12 +710,12 @@ void DequeTest_test_2_2(void)
 	assert(IntDeque_size(id) == MAX);
 	assert(!IntDeque_empty(id));
 	/* front */
-	assert(IntDeque_front(id) == piyo[0]);
+	assert(*IntDeque_front(id) == piyo[0]);
 	/* back */
-	assert(IntDeque_back(id) == piyo[MAX-1]);
+	assert(*IntDeque_back(id) == piyo[MAX-1]);
 	/* pop_front */
 	size = IntDeque_size(id);
-	assert(IntDeque_pop_front(id) == piyo[0]);
+	IntDeque_pop_front(id);
 	assert(IntDeque_size(id) == size - 1);
 	/* push_back */
 	size = IntDeque_size(id);
@@ -722,9 +729,11 @@ void DequeTest_test_2_2(void)
 	for (i = 0; i < MAX; i++) {
 		size = IntDeque_size(id);
 		if (i < MAX-1) {
-			assert(IntDeque_pop_front(id) == piyo[i+1]);
+			assert(*IntDeque_front(id) == piyo[i+1]);
+			IntDeque_pop_front(id);
 		} else {
-			assert(IntDeque_pop_front(id) == piyo[0]);
+			assert(*IntDeque_front(id) == piyo[0]);
+			IntDeque_pop_front(id);
 		}
 		assert(IntDeque_size(id) == size - 1);
 	}
@@ -738,7 +747,7 @@ void DequeTest_test_2_2(void)
 	assert(IntDeque_size(id) == c);
 	assert(!IntDeque_empty(id));
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	IntDeque_delete(id);
 }
 
@@ -761,13 +770,15 @@ void DequeTest_test_2_3(void)
 	assert(IntDeque_size(id) == MAX);
 	assert(!IntDeque_empty(id));
 	/* front */
-	assert(IntDeque_front(id) == piyo[0]);
+	assert(*IntDeque_front(id) == piyo[0]);
 	/* back */
-	assert(IntDeque_back(id) == piyo[MAX-1]);
+	assert(*IntDeque_back(id) == piyo[MAX-1]);
 	/* pop_back */
 	size = IntDeque_size(id);
-	assert(IntDeque_pop_back(id) == piyo[MAX-1]);
-	assert(IntDeque_pop_back(id) == piyo[MAX-2]);
+	assert(*IntDeque_back(id) == piyo[MAX-1]);
+	IntDeque_pop_back(id);
+	assert(*IntDeque_back(id) == piyo[MAX-2]);
+	IntDeque_pop_back(id);
 	assert(IntDeque_size(id) == size - 2);
 	/* push_front */
 	size = IntDeque_size(id);
@@ -781,11 +792,14 @@ void DequeTest_test_2_3(void)
 	/* pop_back */
 	for (i = MAX-3; i >= 0; i--) {
 		size = IntDeque_size(id);
-		assert(IntDeque_pop_back(id) == piyo[i]);
+		assert(*IntDeque_back(id) == piyo[i]);
+		IntDeque_pop_back(id);
 		assert(IntDeque_size(id) == size - 1);
 	}
-	assert(IntDeque_pop_back(id) == piyo[MAX-1]);
-	assert(IntDeque_pop_back(id) == piyo[MAX-2]);
+	assert(*IntDeque_back(id) == piyo[MAX-1]);
+	IntDeque_pop_back(id);
+	assert(*IntDeque_back(id) == piyo[MAX-2]);
+	IntDeque_pop_back(id);
 
 	assert(IntDeque_size(id) == 0);
 	assert(IntDeque_empty(id));
@@ -797,7 +811,7 @@ void DequeTest_test_2_3(void)
 	assert(IntDeque_size(id) == c);
 	assert(!IntDeque_empty(id));
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	IntDeque_delete(id);
 }
 
@@ -880,7 +894,7 @@ void DequeTest_test_2_4(void)
 	}
 	assert(IntDeque_size(id) == 0);
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	IntDeque_delete(id);
 }
 
@@ -1006,7 +1020,7 @@ void DequeTest_test_2_5(void)
 	IntDeque_erase(id, 0, IntDeque_size(id));
 	assert(IntDeque_size(id) == 0);
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	IntDeque_delete(id);
 }
 
@@ -1039,11 +1053,11 @@ void DequeTest_run(void)
 int main(void)
 {
 #ifdef MY_MALLOC
-	Heap_init(&heap, buf, sizeof buf, sizeof buf[0]);
+	Pool_init(&pool, buf, sizeof buf, sizeof buf[0]);
 #endif
 	DequeTest_run();
 #ifdef MY_MALLOC
-	HEAP_DUMP_LEAK(&heap, 0);
+	POOL_DUMP_LEAK(&pool, 0);
 #endif
 	return 0;
 }
