@@ -5,13 +5,13 @@
 #include "../cstl/ring.h"
 #include "../cstl/set.h"
 #include "rbtree_debug.h"
-#include "heap.h"
+#include "Pool.h"
 #ifdef MY_MALLOC
 double buf[1024*1024/sizeof(double)];
-Heap heap;
-#define malloc(s)		Heap_alloc(&heap, s)
-#define realloc(p, s)	Heap_realloc(&heap, p, s)
-#define free(p)			Heap_free(&heap, p)
+Pool pool;
+#define malloc(s)		Pool_malloc(&pool, s)
+#define realloc(p, s)	Pool_realloc(&pool, p, s)
+#define free(p)			Pool_free(&pool, p)
 #endif
 
 
@@ -125,7 +125,7 @@ void set_init_hoge(void)
 /*        printf("%4d: int[%3d], double[%5g], ptr[%p], str[%s]\n",*/
 /*                i, hoge_int[i], hoge_double[i], hoge_ptr[i], hoge_str[i]);*/
 	}
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	IntRing_delete(q);
 }
 
@@ -169,18 +169,18 @@ void SetTest_test_1_1(void)
 		assert(pos[i] == IntSetA_upper_bound(ia, hoge_int[i]-1));
 		assert(IntSetA_lower_bound(ia, hoge_int[i]+1) == IntSetA_upper_bound(ia, hoge_int[i]));
 	}
-	assert(IntSetA_find(ia, IntSetA_key(IntSetA_begin(ia)) -1) == IntSetA_end(ia));
-	assert(IntSetA_lower_bound(ia, IntSetA_key(IntSetA_rbegin(ia)) +1) == IntSetA_end(ia));
-	assert(IntSetA_upper_bound(ia, IntSetA_key(IntSetA_rbegin(ia))) == IntSetA_end(ia));
+	assert(IntSetA_find(ia, *IntSetA_data(IntSetA_begin(ia)) -1) == IntSetA_end(ia));
+	assert(IntSetA_lower_bound(ia, *IntSetA_data(IntSetA_rbegin(ia)) +1) == IntSetA_end(ia));
+	assert(IntSetA_upper_bound(ia, *IntSetA_data(IntSetA_rbegin(ia))) == IntSetA_end(ia));
 	/* begin, end, next, key */
 	for (p = IntSetA_begin(ia), i = 0; p != IntSetA_end(ia); p = IntSetA_next(p), i++) {
-		assert(IntSetA_key(p) == i);
+		assert(*IntSetA_data(p) == i);
 	}
 	assert(i == SIZE/2);
 	assert(IntSetA_next(IntSetA_rbegin(ia)) == IntSetA_end(ia));
 	/* rbegin, rend, prev, key */
 	for (p = IntSetA_rbegin(ia), i = SIZE/2 -1; p != IntSetA_rend(ia); p = IntSetA_prev(p), i--) {
-		assert(IntSetA_key(p) == i);
+		assert(*IntSetA_data(p) == i);
 	}
 	assert(i == -1);
 	assert(IntSetA_prev(IntSetA_begin(ia)) == IntSetA_rend(ia));
@@ -291,7 +291,7 @@ void SetTest_test_1_1(void)
 	assert(IntSetA_verify(ia));
 	assert(IntSetA_verify(x));
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	IntSetA_delete(ia);
 	IntSetA_delete(x);
 }
@@ -333,18 +333,18 @@ void SetTest_test_1_2(void)
 		assert(pos[i] == IntSetD_upper_bound(id, hoge_int[i]+1));
 		assert(IntSetD_lower_bound(id, hoge_int[i]-1) == IntSetD_upper_bound(id, hoge_int[i]));
 	}
-	assert(IntSetD_find(id, IntSetD_key(IntSetD_begin(id)) +1) == IntSetD_end(id));
-	assert(IntSetD_lower_bound(id, IntSetD_key(IntSetD_rbegin(id)) -1) == IntSetD_end(id));
-	assert(IntSetD_upper_bound(id, IntSetD_key(IntSetD_rbegin(id))) == IntSetD_end(id));
+	assert(IntSetD_find(id, *IntSetD_data(IntSetD_begin(id)) +1) == IntSetD_end(id));
+	assert(IntSetD_lower_bound(id, *IntSetD_data(IntSetD_rbegin(id)) -1) == IntSetD_end(id));
+	assert(IntSetD_upper_bound(id, *IntSetD_data(IntSetD_rbegin(id))) == IntSetD_end(id));
 	/* begin, end, next, key */
 	for (p = IntSetD_begin(id), i = SIZE/2 -1; p != IntSetD_end(id); p = IntSetD_next(p), i--) {
-		assert(IntSetD_key(p) == i);
+		assert(*IntSetD_data(p) == i);
 	}
 	assert(i == -1);
 	assert(IntSetD_next(IntSetD_rbegin(id)) == IntSetD_end(id));
 	/* rbegin, rend, prev, key */
 	for (p = IntSetD_rbegin(id), i = 0; p != IntSetD_rend(id); p = IntSetD_prev(p), i++) {
-		assert(IntSetD_key(p) == i);
+		assert(*IntSetD_data(p) == i);
 	}
 	assert(i == SIZE/2);
 	assert(IntSetD_prev(IntSetD_begin(id)) == IntSetD_rend(id));
@@ -396,7 +396,7 @@ void SetTest_test_1_2(void)
 	assert(IntSetD_size(id) == count);
 	printf("count: %d\n", count);
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	IntSetD_delete(id);
 }
 
@@ -453,18 +453,18 @@ void SetTest_test_1_3(void)
 		}
 		assert(IntMSetA_lower_bound(ima, hoge_int[i]+1) == IntMSetA_upper_bound(ima, hoge_int[i]));
 	}
-	assert(IntMSetA_find(ima, IntMSetA_key(IntMSetA_begin(ima)) -1) == IntMSetA_end(ima));
-	assert(IntMSetA_lower_bound(ima, IntMSetA_key(IntMSetA_rbegin(ima)) +1) == IntMSetA_end(ima));
-	assert(IntMSetA_upper_bound(ima, IntMSetA_key(IntMSetA_rbegin(ima))) == IntMSetA_end(ima));
+	assert(IntMSetA_find(ima, *IntMSetA_data(IntMSetA_begin(ima)) -1) == IntMSetA_end(ima));
+	assert(IntMSetA_lower_bound(ima, *IntMSetA_data(IntMSetA_rbegin(ima)) +1) == IntMSetA_end(ima));
+	assert(IntMSetA_upper_bound(ima, *IntMSetA_data(IntMSetA_rbegin(ima))) == IntMSetA_end(ima));
 	/* begin, end, next, key */
 	for (p = IntMSetA_begin(ima), i = 0; p != IntMSetA_end(ima); p = IntMSetA_next(p), i++) {
-/*        printf("%d, %d\n", i, IntMSetA_key(p));*/
+/*        printf("%d, %d\n", i, *IntMSetA_data(p));*/
 	}
 	assert(i == SIZE);
 	assert(IntMSetA_next(IntMSetA_rbegin(ima)) == IntMSetA_end(ima));
 	/* rbegin, rend, prev, key */
 	for (p = IntMSetA_rbegin(ima), i = SIZE -1; p != IntMSetA_rend(ima); p = IntMSetA_prev(p), i--) {
-/*        printf("%d, %d\n", i, IntMSetA_key(p));*/
+/*        printf("%d, %d\n", i, *IntMSetA_data(p));*/
 	}
 	assert(i == -1);
 	assert(IntMSetA_prev(IntMSetA_begin(ima)) == IntMSetA_rend(ima));
@@ -549,7 +549,7 @@ void SetTest_test_1_3(void)
 	assert(IntMSetA_size(x) == sizeof b / sizeof b[0] + SIZE);
 
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	IntMSetA_delete(ima);
 	IntMSetA_delete(x);
 }
@@ -590,18 +590,18 @@ void SetTest_test_2_1(void)
 		assert(pos[i] == DoubleSetA_upper_bound(da, hoge_double[i]-0.5));
 		assert(DoubleSetA_lower_bound(da, hoge_double[i]+0.5) == DoubleSetA_upper_bound(da, hoge_double[i]));
 	}
-	assert(DoubleSetA_find(da, DoubleSetA_key(DoubleSetA_begin(da)) -1) == DoubleSetA_end(da));
-	assert(DoubleSetA_lower_bound(da, DoubleSetA_key(DoubleSetA_rbegin(da)) +1) == DoubleSetA_end(da));
-	assert(DoubleSetA_upper_bound(da, DoubleSetA_key(DoubleSetA_rbegin(da))) == DoubleSetA_end(da));
+	assert(DoubleSetA_find(da, *DoubleSetA_data(DoubleSetA_begin(da)) -1) == DoubleSetA_end(da));
+	assert(DoubleSetA_lower_bound(da, *DoubleSetA_data(DoubleSetA_rbegin(da)) +1) == DoubleSetA_end(da));
+	assert(DoubleSetA_upper_bound(da, *DoubleSetA_data(DoubleSetA_rbegin(da))) == DoubleSetA_end(da));
 	/* begin, end, next, key */
 	for (p = DoubleSetA_begin(da), i = 0; p != DoubleSetA_end(da); p = DoubleSetA_next(p), i++) {
-		assert(DoubleSetA_key(p) == i*0.5);
+		assert(*DoubleSetA_data(p) == i*0.5);
 	}
 	assert(i == SIZE/2);
 	assert(DoubleSetA_next(DoubleSetA_rbegin(da)) == DoubleSetA_end(da));
 	/* rbegin, rend, prev, key */
 	for (p = DoubleSetA_rbegin(da), i = SIZE/2 -1; p != DoubleSetA_rend(da); p = DoubleSetA_prev(p), i--) {
-		assert(DoubleSetA_key(p) == i*0.5);
+		assert(*DoubleSetA_data(p) == i*0.5);
 	}
 	assert(i == -1);
 	assert(DoubleSetA_prev(DoubleSetA_begin(da)) == DoubleSetA_rend(da));
@@ -664,7 +664,7 @@ void SetTest_test_2_1(void)
 	DoubleSetA_clear(da);
 	assert(DoubleSetA_size(da) == 0);
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	DoubleSetA_delete(da);
 }
 
@@ -705,18 +705,18 @@ void SetTest_test_3_1(void)
 		assert(pos[i] == PtrSetA_upper_bound(pa, hoge_ptr[i]-1));
 		assert(PtrSetA_lower_bound(pa, hoge_ptr[i]+1) == PtrSetA_upper_bound(pa, hoge_ptr[i]));
 	}
-	assert(PtrSetA_find(pa, PtrSetA_key(PtrSetA_begin(pa)) -1) == PtrSetA_end(pa));
-	assert(PtrSetA_lower_bound(pa, PtrSetA_key(PtrSetA_rbegin(pa)) +1) == PtrSetA_end(pa));
-	assert(PtrSetA_upper_bound(pa, PtrSetA_key(PtrSetA_rbegin(pa))) == PtrSetA_end(pa));
+	assert(PtrSetA_find(pa, *PtrSetA_data(PtrSetA_begin(pa)) -1) == PtrSetA_end(pa));
+	assert(PtrSetA_lower_bound(pa, *PtrSetA_data(PtrSetA_rbegin(pa)) +1) == PtrSetA_end(pa));
+	assert(PtrSetA_upper_bound(pa, *PtrSetA_data(PtrSetA_rbegin(pa))) == PtrSetA_end(pa));
 	/* begin, end, next, key */
 	for (p = PtrSetA_begin(pa), i = 0; p != PtrSetA_end(pa); p = PtrSetA_next(p), i++) {
-		assert(PtrSetA_key(p) == &hoge_int[i]);
+		assert(*PtrSetA_data(p) == &hoge_int[i]);
 	}
 	assert(i == SIZE/2);
 	assert(PtrSetA_next(PtrSetA_rbegin(pa)) == PtrSetA_end(pa));
 	/* rbegin, rend, prev, key */
 	for (p = PtrSetA_rbegin(pa), i = SIZE/2 -1; p != PtrSetA_rend(pa); p = PtrSetA_prev(p), i--) {
-		assert(PtrSetA_key(p) == &hoge_int[i]);
+		assert(*PtrSetA_data(p) == &hoge_int[i]);
 	}
 	assert(i == -1);
 	assert(PtrSetA_prev(PtrSetA_begin(pa)) == PtrSetA_rend(pa));
@@ -780,7 +780,7 @@ void SetTest_test_3_1(void)
 	PtrSetA_clear(pa);
 	assert(PtrSetA_size(pa) == 0);
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	PtrSetA_delete(pa);
 }
 
@@ -825,16 +825,16 @@ void SetTest_test_4_1(void)
 	}
 	assert(StrSetA_find(sa, "hoge") == StrSetA_end(sa));
 	assert(StrSetA_lower_bound(sa, "hoge") == StrSetA_end(sa));
-	assert(StrSetA_upper_bound(sa, StrSetA_key(StrSetA_rbegin(sa))) == StrSetA_end(sa));
+	assert(StrSetA_upper_bound(sa, *StrSetA_data(StrSetA_rbegin(sa))) == StrSetA_end(sa));
 	/* begin, end, next, key */
 	for (p = StrSetA_begin(sa), i = 0; p != StrSetA_end(sa); p = StrSetA_next(p), i++) {
-		assert(StrSetA_key(p) == hoge_str[i]);
+		assert(*StrSetA_data(p) == hoge_str[i]);
 	}
 	assert(i == SIZE/2);
 	assert(StrSetA_next(StrSetA_rbegin(sa)) == StrSetA_end(sa));
 	/* rbegin, rend, prev, key */
 	for (p = StrSetA_rbegin(sa), i = SIZE/2 -1; p != StrSetA_rend(sa); p = StrSetA_prev(p), i--) {
-		assert(StrSetA_key(p) == hoge_str[i]);
+		assert(*StrSetA_data(p) == hoge_str[i]);
 	}
 	assert(i == -1);
 	assert(StrSetA_prev(StrSetA_begin(sa)) == StrSetA_rend(sa));
@@ -897,7 +897,7 @@ void SetTest_test_4_1(void)
 	StrSetA_clear(sa);
 	assert(StrSetA_size(sa) == 0);
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	StrSetA_delete(sa);
 }
 
@@ -943,18 +943,18 @@ void SetTest_test_5_1(void)
 		}
 		assert(UIntSetA_lower_bound(uia, hoge_int[i]+1) == UIntSetA_upper_bound(uia, hoge_int[i]));
 	}
-	assert(UIntSetA_find(uia, UIntSetA_key(UIntSetA_begin(uia)) -1) == UIntSetA_end(uia));
-	assert(UIntSetA_lower_bound(uia, UIntSetA_key(UIntSetA_rbegin(uia)) +1) == UIntSetA_end(uia));
-	assert(UIntSetA_upper_bound(uia, UIntSetA_key(UIntSetA_rbegin(uia))) == UIntSetA_end(uia));
+	assert(UIntSetA_find(uia, *UIntSetA_data(UIntSetA_begin(uia)) -1) == UIntSetA_end(uia));
+	assert(UIntSetA_lower_bound(uia, *UIntSetA_data(UIntSetA_rbegin(uia)) +1) == UIntSetA_end(uia));
+	assert(UIntSetA_upper_bound(uia, *UIntSetA_data(UIntSetA_rbegin(uia))) == UIntSetA_end(uia));
 	/* begin, end, next, key */
 	for (p = UIntSetA_begin(uia), i = 0; p != UIntSetA_end(uia); p = UIntSetA_next(p), i++) {
-		assert(UIntSetA_key(p) == i);
+		assert(*UIntSetA_data(p) == i);
 	}
 	assert(i == SIZE/2);
 	assert(UIntSetA_next(UIntSetA_rbegin(uia)) == UIntSetA_end(uia));
 	/* rbegin, rend, prev, key */
 	for (p = UIntSetA_rbegin(uia), i = SIZE/2 -1; p != UIntSetA_rend(uia); p = UIntSetA_prev(p), i--) {
-		assert(UIntSetA_key(p) == i);
+		assert(*UIntSetA_data(p) == i);
 	}
 	assert(i == -1);
 	assert(UIntSetA_prev(UIntSetA_begin(uia)) == UIntSetA_rend(uia));
@@ -1017,22 +1017,13 @@ void SetTest_test_5_1(void)
 	UIntSetA_clear(uia);
 	assert(UIntSetA_size(uia) == 0);
 
-	HEAP_DUMP_OVERFLOW(&heap);
+	POOL_DUMP_OVERFLOW(&pool);
 	UIntSetA_delete(uia);
 }
 
 
 
 
-
-
-
-
-
-
-
-
-
 void SetTest_run(void)
 {
 	printf("\n===== set test =====\n");
@@ -1045,19 +1036,17 @@ void SetTest_run(void)
 	SetTest_test_3_1();
 	SetTest_test_4_1();
 	SetTest_test_5_1();
-
-
 }
 
 
 int main(void)
 {
 #ifdef MY_MALLOC
-	Heap_init(&heap, buf, sizeof buf, sizeof buf[0]);
+	Pool_init(&pool, buf, sizeof buf, sizeof buf[0]);
 #endif
 	SetTest_run();
 #ifdef MY_MALLOC
-	HEAP_DUMP_LEAK(&heap, 0);
+	POOL_DUMP_LEAK(&pool, 0);
 #endif
 	return 0;
 }
