@@ -1,8 +1,28 @@
-#include "test.h"
+#include <stdio.h>
+#include <string.h>
+#include <assert.h>
+#include "../cstl/vector.h"
+#include "Pool.h"
+#ifdef MY_MALLOC
+double buf[1024*1024/sizeof(double)];
+Pool pool;
+#define malloc(s)		Pool_malloc(&pool, s)
+#define realloc(p, s)	Pool_realloc(&pool, p, s)
+#define free(p)			Pool_free(&pool, p)
+#endif
 
+/* vector */
+#ifdef CSTLGEN
+#include "UCharVector.h"
+#include "IntVector.h"
+#else
 
-VECTOR_IMPLEMENT(UCharVector, unsigned char)
-VECTOR_IMPLEMENT(IntVector, int)
+CSTL_VECTOR_INTERFACE(UCharVector, unsigned char)
+CSTL_VECTOR_INTERFACE(IntVector, int)
+
+CSTL_VECTOR_IMPLEMENT(UCharVector, unsigned char)
+CSTL_VECTOR_IMPLEMENT(IntVector, int)
+#endif
 
 static UCharVector *uv;
 static IntVector *iv;
@@ -34,7 +54,7 @@ void VectorTest_test_1_1(void)
 {
 	size_t a;
 	printf("***** test_1_1 *****\n");
-	uv = UCharVector_new(SIZE);
+	uv = UCharVector_new_reserve(SIZE);
 	vector_init_hoge();
 	/* 初期状態 */
 	assert(UCharVector_capacity(uv) == SIZE);
@@ -85,6 +105,13 @@ void VectorTest_test_1_1(void)
 	assert(UCharVector_size(uv) == 0);
 	assert(UCharVector_empty(uv));
 
+	POOL_DUMP_OVERFLOW(&pool);
+	UCharVector_delete(uv);
+
+	/* new */
+	uv = UCharVector_new();
+	assert(UCharVector_size(uv) == 0);
+	assert(UCharVector_empty(uv));
 	UCharVector_delete(uv);
 }
 
@@ -93,14 +120,14 @@ void VectorTest_test_1_2(void)
 	int i;
 	size_t a;
 	printf("***** test_1_2 *****\n");
-	uv = UCharVector_new(SIZE);
+	uv = UCharVector_new_reserve(SIZE);
 	vector_init_hoge();
 	/* push_back */
 	for (i = 0; i < SIZE; i++) {
 		assert(UCharVector_push_back(uv, hoge[i]));
 		assert(UCharVector_size(uv) == i+1);
-		assert(UCharVector_front(uv) == hoge[0]);
-		assert(UCharVector_back(uv) == hoge[i]);
+		assert(*UCharVector_front(uv) == hoge[0]);
+		assert(*UCharVector_back(uv) == hoge[i]);
 	}
 	assert(memcmp(UCharVector_at(uv, 0), hoge, SIZE) == 0);
 	assert(UCharVector_capacity(uv) == SIZE);
@@ -109,8 +136,8 @@ void VectorTest_test_1_2(void)
 	for (i = i; i < 256; i++) {
 		assert(UCharVector_push_back(uv, hoge[i]));
 		assert(UCharVector_size(uv) == i+1);
-		assert(UCharVector_front(uv) == hoge[0]);
-		assert(UCharVector_back(uv) == hoge[i]);
+		assert(*UCharVector_front(uv) == hoge[0]);
+		assert(*UCharVector_back(uv) == hoge[i]);
 	}
 	assert(memcmp(UCharVector_at(uv, 0), hoge, 256) == 0);
 	a = UCharVector_capacity(uv);
@@ -118,19 +145,20 @@ void VectorTest_test_1_2(void)
 	assert(UCharVector_size(uv) == 256);
 	assert(!UCharVector_empty(uv));
 	/* front, back */
-	assert(UCharVector_front(uv) == hoge[0]);
-	assert(UCharVector_back(uv) == hoge[255]);
+	assert(*UCharVector_front(uv) == hoge[0]);
+	assert(*UCharVector_back(uv) == hoge[255]);
 	/* pop_back */
 	for (i = 255; i >= 0; i--) {
-		assert(UCharVector_front(uv) == hoge[0]);
-		assert(UCharVector_back(uv) == hoge[i]);
-		assert(UCharVector_pop_back(uv) == hoge[i]);
+		assert(*UCharVector_front(uv) == hoge[0]);
+		assert(*UCharVector_back(uv) == hoge[i]);
+		UCharVector_pop_back(uv);
 		assert(UCharVector_size(uv) == i);
 	}
 	assert(UCharVector_size(uv) == 0);
 	assert(UCharVector_empty(uv));
 	assert(UCharVector_capacity(uv) == a);
 
+	POOL_DUMP_OVERFLOW(&pool);
 	UCharVector_delete(uv);
 }
 
@@ -138,7 +166,7 @@ void VectorTest_test_1_3(void)
 {
 	int i;
 	printf("***** test_1_3 *****\n");
-	uv = UCharVector_new(SIZE);
+	uv = UCharVector_new_reserve(SIZE);
 	vector_init_hoge();
 	/* insert_array */
 	UCharVector_clear(uv);
@@ -157,6 +185,7 @@ void VectorTest_test_1_3(void)
 	assert(UCharVector_size(uv) == SIZE);
 	assert(!UCharVector_empty(uv));
 
+	POOL_DUMP_OVERFLOW(&pool);
 	UCharVector_delete(uv);
 }
 
@@ -165,7 +194,7 @@ void VectorTest_test_1_4(void)
 	int i;
 	unsigned char buf[256];
 	printf("***** test_1_4 *****\n");
-	uv = UCharVector_new(SIZE);
+	uv = UCharVector_new_reserve(SIZE);
 	/* insert */
 	for (i = 0; i < SIZE; i++) {
 		assert(UCharVector_insert(uv, 0, hoge[i]));
@@ -203,13 +232,14 @@ void VectorTest_test_1_4(void)
 	}
 	assert(UCharVector_size(uv) == 0);
 
+	POOL_DUMP_OVERFLOW(&pool);
 	UCharVector_delete(uv);
 }
 
 void VectorTest_test_1_5(void)
 {
 	printf("***** test_1_5 *****\n");
-	uv = UCharVector_new(SIZE);
+	uv = UCharVector_new_reserve(SIZE);
 	vector_init_hoge();
 	/* insert_array */
 	assert(UCharVector_insert_array(uv, 0, hoge, SIZE));
@@ -255,6 +285,7 @@ void VectorTest_test_1_5(void)
 	UCharVector_erase(uv, 0, SIZE);
 	assert(UCharVector_size(uv) == 0);
 
+	POOL_DUMP_OVERFLOW(&pool);
 	UCharVector_delete(uv);
 }
 
@@ -263,8 +294,9 @@ void VectorTest_test_1_6(void)
 	UCharVector *x;
 	size_t i;
 	unsigned char b[] = {1, 2, 4, 43, 2, 54, 1, 0, 2, 24};
+	size_t cap1, cap2;
 	printf("***** test_1_6 *****\n");
-	uv = UCharVector_new(SIZE);
+	uv = UCharVector_new_reserve(SIZE);
 	vector_init_hoge();
 
 	UCharVector_clear(uv);
@@ -305,51 +337,97 @@ void VectorTest_test_1_6(void)
 	UCharVector_shrink(uv, 0);
 	assert(UCharVector_capacity(uv) == 10);
 	assert(UCharVector_size(uv) == 10);
-	/* assign */
-	x = UCharVector_new(SIZE);
-	assert(UCharVector_assign(x, uv, 0, UCharVector_size(uv)));
-	assert(UCharVector_size(x) == 10);
-	for (i = 0; i < UCharVector_size(uv); i++) {
-		assert(*UCharVector_at(x, i) == *UCharVector_at(uv, i));
-	}
-	assert(UCharVector_assign(x, x, 0, UCharVector_size(x)));
-	assert(UCharVector_size(uv) == UCharVector_size(x));
-	for (i = 0; i < UCharVector_size(uv); i++) {
-		assert(*UCharVector_at(x, i) == *UCharVector_at(uv, i));
-	}
-	assert(UCharVector_assign(x, x, 1, 2));
-	assert(UCharVector_size(x) == 2);
-	assert(*UCharVector_at(x, 0) == *UCharVector_at(uv, 1));
-	assert(*UCharVector_at(x, 1) == *UCharVector_at(uv, 2));
-	assert(UCharVector_assign(x, x, 0, 0));
-	assert(UCharVector_size(x) == 0);
 	/* swap */
+	x = UCharVector_new_reserve(SIZE);
 	UCharVector_clear(uv);
 	UCharVector_shrink(uv, 0);
 	UCharVector_clear(uv);
 	assert(UCharVector_insert_array(uv, 0, hoge, SIZE));
 	assert(memcmp(UCharVector_at(uv, 0), hoge, SIZE) == 0);
 	assert(UCharVector_size(uv) == SIZE);
-	assert(UCharVector_capacity(uv) == SIZE);
+	cap1 = UCharVector_capacity(uv);
 	UCharVector_clear(x);
 	UCharVector_shrink(x, 0);
 	UCharVector_clear(x);
 	assert(UCharVector_insert_array(x, 0, b, sizeof b));
 	assert(memcmp(UCharVector_at(x, 0), b, sizeof b) == 0);
 	assert(UCharVector_size(x) == sizeof b);
-	assert(UCharVector_capacity(x) == sizeof b);
+	cap2 = UCharVector_capacity(x);
 
 	UCharVector_swap(uv, x);
 
 	assert(memcmp(UCharVector_at(uv, 0), b, sizeof b) == 0);
 	assert(UCharVector_size(uv) == sizeof b);
-	assert(UCharVector_capacity(uv) == sizeof b);
+	assert(UCharVector_capacity(uv) == cap2);
 	assert(memcmp(UCharVector_at(x, 0), hoge, SIZE) == 0);
 	assert(UCharVector_size(x) == SIZE);
-	assert(UCharVector_capacity(x) == SIZE);
+	assert(UCharVector_capacity(x) == cap1);
+	/* insert_range */
+	UCharVector_clear(uv);
+	UCharVector_shrink(uv, 0);
+	UCharVector_clear(x);
+	UCharVector_shrink(x, 0);
+	assert(UCharVector_insert_array(uv, 0, hoge, SIZE));
+	assert(UCharVector_insert_array(x, 0, b, sizeof b));
+	assert(UCharVector_insert_range(uv, 0, x, 0, sizeof b));
+	for (i = 0; i < UCharVector_size(uv); i++) {
+		if (i < sizeof b) {
+			assert(*UCharVector_at(uv, i) == *UCharVector_at(x, i));
+		} else {
+			assert(*UCharVector_at(uv, i) == hoge[i - sizeof b]);
+		}
+		printf("%02d ", *UCharVector_at(uv, i));
+	}
+	printf("\n");
+	UCharVector_clear(uv);
+	assert(UCharVector_insert_array(uv, 0, hoge, SIZE));
+	for (i = 0; i < UCharVector_size(uv); i++) {
+		printf("%02d ", *UCharVector_at(uv, i));
+	}
+	printf("\n");
+
+	assert(UCharVector_insert_range(uv, 0, uv, 1, 4));
+	for (i = 0; i < UCharVector_size(uv); i++) {
+		if (i < 4) {
+			assert(*UCharVector_at(uv, i) == hoge[1 + i]);
+		} else {
+			assert(*UCharVector_at(uv, i) == hoge[i - 4]);
+		}
+		printf("%02d ", *UCharVector_at(uv, i));
+	}
+	printf("\n");
+	UCharVector_clear(uv);
+	assert(UCharVector_insert_array(uv, 0, hoge, SIZE));
+	assert(UCharVector_insert_range(uv, 3, uv, 1, 4));
+	for (i = 0; i < UCharVector_size(uv); i++) {
+		if (i < 3) {
+			assert(*UCharVector_at(uv, i) == hoge[i]);
+		} else if (3 <= i && i < 3 + 4) {
+			assert(*UCharVector_at(uv, i) == hoge[1 + i - 3]);
+		} else {
+			assert(*UCharVector_at(uv, i) == hoge[i - 4]);
+		}
+		printf("%02d ", *UCharVector_at(uv, i));
+	}
+	printf("\n");
+	UCharVector_clear(uv);
+	assert(UCharVector_insert_array(uv, 0, hoge, SIZE));
+	assert(UCharVector_insert_range(uv, 5, uv, 1, 4));
+	for (i = 0; i < UCharVector_size(uv); i++) {
+		if (i < 5) {
+			assert(*UCharVector_at(uv, i) == hoge[i]);
+		} else if (5 <= i && i < 5 + 4) {
+			assert(*UCharVector_at(uv, i) == hoge[1 + i - 5]);
+		} else {
+			assert(*UCharVector_at(uv, i) == hoge[i - 4]);
+		}
+		printf("%02d ", *UCharVector_at(uv, i));
+	}
+	printf("\n");
 
 
 
+	POOL_DUMP_OVERFLOW(&pool);
 	UCharVector_delete(uv);
 	UCharVector_delete(x);
 }
@@ -359,7 +437,7 @@ void VectorTest_test_2_1(void)
 {
 	size_t a;
 	printf("***** test_2_1 *****\n");
-	iv = IntVector_new(SIZE);
+	iv = IntVector_new_reserve(SIZE);
 	vector_init_piyo();
 	/* 初期状態 */
 	assert(IntVector_capacity(iv) == SIZE);
@@ -410,6 +488,7 @@ void VectorTest_test_2_1(void)
 	assert(IntVector_size(iv) == 0);
 	assert(IntVector_empty(iv));
 
+	POOL_DUMP_OVERFLOW(&pool);
 	IntVector_delete(iv);
 }
 
@@ -418,14 +497,14 @@ void VectorTest_test_2_2(void)
 	int i;
 	size_t a;
 	printf("***** test_2_2 *****\n");
-	iv = IntVector_new(SIZE);
+	iv = IntVector_new_reserve(SIZE);
 	vector_init_piyo();
 	/* push_back */
 	for (i = 0; i < SIZE; i++) {
 		assert(IntVector_push_back(iv, piyo[i]));
 		assert(IntVector_size(iv) == i+1);
-		assert(IntVector_front(iv) == piyo[0]);
-		assert(IntVector_back(iv) == piyo[i]);
+		assert(*IntVector_front(iv) == piyo[0]);
+		assert(*IntVector_back(iv) == piyo[i]);
 	}
 	assert(memcmp(IntVector_at(iv, 0), piyo, SIZE) == 0);
 	assert(IntVector_capacity(iv) == SIZE);
@@ -434,8 +513,8 @@ void VectorTest_test_2_2(void)
 	for (i = i; i < 256; i++) {
 		assert(IntVector_push_back(iv, piyo[i]));
 		assert(IntVector_size(iv) == i+1);
-		assert(IntVector_front(iv) == piyo[0]);
-		assert(IntVector_back(iv) == piyo[i]);
+		assert(*IntVector_front(iv) == piyo[0]);
+		assert(*IntVector_back(iv) == piyo[i]);
 	}
 	assert(memcmp(IntVector_at(iv, 0), piyo, 256) == 0);
 	a = IntVector_capacity(iv);
@@ -443,19 +522,20 @@ void VectorTest_test_2_2(void)
 	assert(IntVector_size(iv) == 256);
 	assert(!IntVector_empty(iv));
 	/* front, back */
-	assert(IntVector_front(iv) == piyo[0]);
-	assert(IntVector_back(iv) == piyo[255]);
+	assert(*IntVector_front(iv) == piyo[0]);
+	assert(*IntVector_back(iv) == piyo[255]);
 	/* pop_back */
 	for (i = 255; i >= 0; i--) {
-		assert(IntVector_front(iv) == piyo[0]);
-		assert(IntVector_back(iv) == piyo[i]);
-		assert(IntVector_pop_back(iv) == piyo[i]);
+		assert(*IntVector_front(iv) == piyo[0]);
+		assert(*IntVector_back(iv) == piyo[i]);
+		IntVector_pop_back(iv);
 		assert(IntVector_size(iv) == i);
 	}
 	assert(IntVector_size(iv) == 0);
 	assert(IntVector_empty(iv));
 	assert(IntVector_capacity(iv) == a);
 
+	POOL_DUMP_OVERFLOW(&pool);
 	IntVector_delete(iv);
 }
 
@@ -463,7 +543,7 @@ void VectorTest_test_2_3(void)
 {
 	int i;
 	printf("***** test_2_3 *****\n");
-	iv = IntVector_new(SIZE);
+	iv = IntVector_new_reserve(SIZE);
 	vector_init_piyo();
 	/* insert_array */
 	IntVector_clear(iv);
@@ -482,6 +562,7 @@ void VectorTest_test_2_3(void)
 	assert(IntVector_size(iv) == SIZE);
 	assert(!IntVector_empty(iv));
 
+	POOL_DUMP_OVERFLOW(&pool);
 	IntVector_delete(iv);
 }
 
@@ -490,7 +571,7 @@ void VectorTest_test_2_4(void)
 	int i;
 	int buf[256];
 	printf("***** test_2_4 *****\n");
-	iv = IntVector_new(SIZE);
+	iv = IntVector_new_reserve(SIZE);
 	/* insert */
 	for (i = 0; i < SIZE; i++) {
 		assert(IntVector_insert(iv, 0, piyo[i]));
@@ -528,13 +609,14 @@ void VectorTest_test_2_4(void)
 	}
 	assert(IntVector_size(iv) == 0);
 
+	POOL_DUMP_OVERFLOW(&pool);
 	IntVector_delete(iv);
 }
 
 void VectorTest_test_2_5(void)
 {
 	printf("***** test_2_5 *****\n");
-	iv = IntVector_new(SIZE);
+	iv = IntVector_new_reserve(SIZE);
 	vector_init_piyo();
 	/* insert_array */
 	assert(IntVector_insert_array(iv, 0, piyo, SIZE));
@@ -574,6 +656,7 @@ void VectorTest_test_2_5(void)
 	IntVector_erase(iv, 0, SIZE);
 	assert(IntVector_size(iv) == 0);
 
+	POOL_DUMP_OVERFLOW(&pool);
 	IntVector_delete(iv);
 }
 
@@ -596,3 +679,15 @@ void VectorTest_run(void)
 	VectorTest_test_2_5();
 }
 
+
+int main(void)
+{
+#ifdef MY_MALLOC
+	Pool_init(&pool, buf, sizeof buf, sizeof buf[0]);
+#endif
+	VectorTest_run();
+#ifdef MY_MALLOC
+	POOL_DUMP_LEAK(&pool, 0);
+#endif
+	return 0;
+}
